A sample dataset with six conservation agriculture treatments in an arid pulse-based cropping system from western Rajasthan, India. Includes water, energy, food, nutrient, and carbon data for WEFNC nexus analysis.

arid_pulse_nexus

Format

A data frame with 6 rows and 26 variables:

treatment

Character. Treatment combination name

tillage

Character. Tillage method: CT (conventional), ZT (zero), PB (permanent beds)

irrigation

Character. Irrigation method: Flood, Sprinkler, Drip, or SSDI (sub-surface drip)

residue

Logical. Whether crop residue was retained

grain_yield

Numeric. Grain yield (kg/ha)

straw_yield

Numeric. Straw yield (kg/ha)

irrigation_applied

Numeric. Irrigation water applied (mm)

effective_rainfall

Numeric. Effective rainfall (mm)

total_water

Numeric. Total water consumed (mm)

crop_et

Numeric. Crop evapotranspiration (mm)

energy_input

Numeric. Total energy input (MJ/ha)

energy_output_grain

Numeric. Energy output from grain (MJ/ha)

energy_output_straw

Numeric. Energy output from straw (MJ/ha)

n_applied

Numeric. Nitrogen applied (kg/ha)

p_applied

Numeric. Phosphorus applied (kg P2O5/ha)

k_applied

Numeric. Potassium applied (kg K2O/ha)

n_uptake

Numeric. Total plant nitrogen uptake (kg/ha)

p_uptake

Numeric. Total plant phosphorus uptake (kg/ha)

grain_n_uptake

Numeric. Grain nitrogen uptake (kg/ha)

diesel_use

Numeric. Diesel consumption (L/ha)

electricity_kwh

Numeric. Electricity consumption (kWh/ha)

soc_pct

Numeric. Soil organic carbon (percent)

bulk_density

Numeric. Soil bulk density (Mg/m3)

ghg_emission

Numeric. Total GHG emission (kg CO2-eq/ha)

cost_cultivation

Numeric. Cost of cultivation (INR/ha)

gross_return

Numeric. Gross return (INR/ha)

Simulated dataset based on typical experimental data from ICAR-Indian Institute of Pulses Research, Regional Centre, Bikaner, Rajasthan, India.

Examples

data(arid_pulse_nexus)
str(arid_pulse_nexus)
#> 'data.frame':	6 obs. of  26 variables:
#>  $ treatment          : chr  "CT+Flood" "CT+Sprinkler" "ZT+Drip" "ZT+Drip+Residue" ...
#>  $ tillage            : chr  "CT" "CT" "ZT" "ZT" ...
#>  $ irrigation         : chr  "Flood" "Sprinkler" "Drip" "Drip" ...
#>  $ residue            : logi  FALSE FALSE FALSE TRUE FALSE TRUE
#>  $ grain_yield        : num  980 1120 1280 1380 1450 1580
#>  $ straw_yield        : num  1450 1680 1850 2050 2180 2350
#>  $ irrigation_applied : num  280 220 160 155 135 130
#>  $ effective_rainfall : num  185 185 185 185 185 185
#>  $ total_water        : num  465 405 345 340 320 315
#>  $ crop_et            : num  390 355 310 305 290 285
#>  $ energy_input       : num  8950 7850 6480 6950 5850 6380
#>  $ energy_output_grain: num  14406 16464 18816 20286 21315 ...
#>  $ energy_output_straw: num  18125 21000 23125 25625 27250 ...
#>  $ n_applied          : num  20 20 20 20 20 20
#>  $ p_applied          : num  40 40 40 40 40 40
#>  $ k_applied          : num  0 0 0 0 0 0
#>  $ n_uptake           : num  32.5 37.8 43.2 48.5 52.1 56.8
#>  $ p_uptake           : num  4.8 5.5 6.3 7.1 7.6 8.2
#>  $ grain_n_uptake     : num  24.5 28.6 33 37.2 40.1 43.8
#>  $ diesel_use         : num  65 55 38 40 32 35
#>  $ electricity_kwh    : num  180 120 75 70 55 50
#>  $ soc_pct            : num  0.32 0.34 0.38 0.42 0.4 0.45
#>  $ bulk_density       : num  1.58 1.56 1.52 1.48 1.5 1.46
#>  $ ghg_emission       : num  1850 1520 1180 1250 1020 1100
#>  $ cost_cultivation   : num  22500 24800 21500 23200 20800 22500
#>  $ gross_return       : num  53900 61600 70400 75900 79750 ...