Computes crop water productivity as the ratio of yield to total evapotranspiration, analogous to the "more crop per drop" concept.
crop_water_productivity(yield, et, verbose = TRUE)Numeric vector. Crop water productivity (kg/m3).
$$CWP = \frac{Y}{ET \times 10}$$ The factor 10 converts mm to m3/ha.
Zwart, S.J. & Bastiaanssen, W.G.M. (2004). Review of measured crop water productivity values for irrigated wheat, rice, cotton and maize. Agricultural Water Management, 69(2), 115-133. doi:10.1016/j.agwat.2004.04.007
crop_water_productivity(yield = 4500, et = 400)
#> Crop water productivity computed (kg/m3).
#> [1] 1.125