Proportion of economic yield to total above-ground biological yield.

harvest_index(economic_yield, biological_yield, verbose = TRUE)

Arguments

economic_yield

Numeric vector. Grain or economic yield (kg/ha).

biological_yield

Numeric vector. Total above-ground biomass yield (kg/ha), which is grain plus straw/stover.

verbose

Logical. If TRUE, prints informational messages. Default TRUE.

Value

Numeric vector. Harvest index as a proportion (0 to 1). A warning is issued if any value exceeds 1.

Details

$$HI = \frac{Y_{econ}}{Y_{biol}}$$

References

Hay, R.K.M. (1995). Harvest index: A review of its use in plant breeding and crop physiology. Annals of Applied Biology, 126(1), 197-216. doi:10.1111/j.1744-7348.1995.tb05015.x

Examples

harvest_index(economic_yield = 4500, biological_yield = 10000)
#> Harvest index computed.
#> [1] 0.45