Ratio of energy output to human labour energy input, measuring the degree of human labour amplification by the farming system.

human_energy_profitability(energy_out, human_energy, verbose = TRUE)

Arguments

energy_out

Numeric vector. Total energy output (MJ/ha).

human_energy

Numeric vector. Human labour energy input (MJ/ha).

verbose

Logical. If TRUE, prints informational messages. Default TRUE.

Value

Numeric vector. Human energy profitability (dimensionless ratio).

Details

Formula: $$HEP = \frac{Energy Output}{Human Energy Input}$$

Examples

human_energy_profitability(energy_out = 135000, human_energy = 180)
#> Human energy profitability computed.
#> [1] 750