Estimates soil organic carbon stock for a given soil depth.

soil_carbon_stock(
  soc_pct,
  bulk_density,
  depth = 30,
  coarse_fraction = 0,
  verbose = TRUE
)

Arguments

soc_pct

Numeric vector. Soil organic carbon content (percent).

bulk_density

Numeric vector. Soil bulk density (Mg/m3 or g/cm3).

depth

Numeric. Soil sampling depth (cm). Default 30.

coarse_fraction

Numeric vector. Volume fraction of coarse fragments greater than 2 mm (0 to 1). Default 0.

verbose

Logical. If TRUE, prints informational messages. Default TRUE.

Value

Numeric vector. SOC stock (Mg C/ha, equivalent to t C/ha).

Details

$$SOC = SOC_{pct} \times BD \times D \times (1 - CF) \times 0.1$$ where BD is bulk density (Mg/m3), D is depth (cm), CF is coarse fraction, and 0.1 is the conversion factor from (percent * Mg/m3 * cm) to Mg/ha.

References

Batjes, N.H. (1996). Total carbon and nitrogen in the soils of the world. European Journal of Soil Science, 47(2), 151-163. doi:10.1111/j.1365-2389.1996.tb01386.x

Examples

soil_carbon_stock(soc_pct = 0.65, bulk_density = 1.45, depth = 30)
#> SOC stock computed (Mg C/ha).
#> [1] 2.83