Computes water use efficiency as the ratio of economic yield to total water consumed (evapotranspiration or irrigation plus rainfall).

water_use_efficiency(yield, water_consumed, verbose = TRUE)

Arguments

yield

Numeric vector. Crop yield (kg/ha).

water_consumed

Numeric vector. Total water consumed (mm), typically evapotranspiration (ET), or irrigation applied plus effective rainfall.

verbose

Logical. If TRUE, prints informational messages. Default TRUE.

Value

Numeric vector. Water use efficiency in kg/ha/mm. Higher values indicate more efficient use of water for crop production.

Details

Water use efficiency is defined as: $$WUE = \frac{Y}{W}$$ where Y is economic yield (kg/ha) and W is total water consumed (mm).

References

Hoover, D.L. et al. (2023). Indicators of water use efficiency across diverse agroecosystems and scales. Science of the Total Environment, 864, 160992. doi:10.1016/j.scitotenv.2022.160992

Examples

# Wheat yield with different irrigation levels
yield <- c(4500, 4200, 3800, 3500)
water <- c(450, 400, 350, 300)
water_use_efficiency(yield, water)
#> WUE computed: 4 values (kg/ha/mm).
#> [1] 10.0000 10.5000 10.8571 11.6667