Ratio of energy output to human labour energy input, measuring the degree of human labour amplification by the farming system.
human_energy_profitability(energy_out, human_energy, verbose = TRUE)Numeric vector. Human energy profitability (dimensionless ratio).
Formula: $$HEP = \frac{Energy Output}{Human Energy Input}$$
human_energy_profitability(energy_out = 135000, human_energy = 180)
#> Human energy profitability computed.
#> [1] 750