Plot method for cf_result
# S3 method for class 'cf_result'
plot(x, ...)
Arguments
- x
An object of class cf_result.
- ...
Additional arguments passed to barplot.
Value
No return value, called for the side effect of generating a
horizontal bar plot showing carbon footprint by emission source.