Computes water use efficiency as the ratio of economic yield to total water consumed (evapotranspiration or irrigation plus rainfall).
water_use_efficiency(yield, water_consumed, verbose = TRUE)Numeric vector. Water use efficiency in kg/ha/mm. Higher values indicate more efficient use of water for crop production.
Water use efficiency is defined as: $$WUE = \frac{Y}{W}$$ where Y is economic yield (kg/ha) and W is total water consumed (mm).
Hoover, D.L. et al. (2023). Indicators of water use efficiency across diverse agroecosystems and scales. Science of the Total Environment, 864, 160992. doi:10.1016/j.scitotenv.2022.160992